accent.context


*gl*cljs

Dynamic binding for WebGL context.

Dynamic binding for WebGL context.
sourceraw docstring

attributes->jscljs

(attributes->js {:keys [alpha depth stencil antialias premultiplied-alpha
                        preserve-drawing-buffer]})
source

default-attributescljs

source

get-contextcljs

(get-context canvas)
(get-context canvas attributes extensions)

Gets a WebGL context from a canvas element. context-attributes may be a map in the following form:

{:alpha
 :depth
 :stencil
 :antialias
 :premultiplied-apha
 :preserve-drawing-buffer}

If you don't specify any key, the default value is assumed. For further information on context creation parameters see

[WebGLContextAttributes] (https://www.khronos.org/registry/webgl/specs/1.0.2/#WEBGLCONTEXTATTRIBUTES);

Gets a WebGL context from a canvas element.
`context-attributes` may be a map in the following form:

    {:alpha
     :depth
     :stencil
     :antialias
     :premultiplied-apha
     :preserve-drawing-buffer}

If you don't specify any key, the default value is assumed.
For further information on context creation parameters see

[WebGLContextAttributes]
(https://www.khronos.org/registry/webgl/specs/1.0.2/#WEBGLCONTEXTATTRIBUTES);
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries