accent.macros


load-linesclj

(load-lines path)

Turns relative path into lines sequence, resolving any found #require statements. #require supports relative path to the source file.

Turns relative path into lines sequence, resolving any found `#require`
statements. `#require` supports relative path to the source file.
sourceraw docstring

load-program!cljmacro

(load-program! relative-uri header)

Creates WebGL program from path to the shader and optional headers to prepend. NOTE: it expect WebGL context to be bound in accent.context

Creates WebGL program from path to the shader and optional headers
to prepend. NOTE: it expect WebGL context to be bound in `accent.context`
sourceraw docstring

with-nodecljmacro

(with-node node & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries