accent.shaders


check-programcljs

(check-program program)

Checks for program (linking) error and throws if one is found.

Checks for program (linking) error and throws if one is found.
sourceraw docstring

check-shadercljs

(check-shader shader)

Checks for shader (compilation) error and throws if one is found.

Checks for shader (compilation) error and throws if one is found.
sourceraw docstring

create-program!cljs

(create-program! shaders)
(create-program! vs-source fs-source)

Creates a program object and checks for linking errors.

Creates a program object and checks for linking errors.
sourceraw docstring

create-shader!cljs

(create-shader! type source)

Creates a shader object from given GLSL source, and checks for compilation errors.

Creates a shader object from given GLSL source,
and checks for compilation errors.
sourceraw docstring

get-program-info-logcljs

(get-program-info-log program)

Return the information log for a program object.

Return the information log for a program object.
sourceraw docstring

get-program-parametercljs

(get-program-parameter program pname)

Return a parameter from a program object.

Return a parameter from a program object.
sourceraw docstring

get-shader-info-logcljs

(get-shader-info-log shader)

Return the information log for a shader object.

Return the information log for a shader object.
sourceraw docstring

get-shader-parametercljs

(get-shader-parameter shader pname)

Return a parameter from a shader object.

Return a parameter from a shader object.
sourceraw docstring

IProgramcljsprotocol

get-attribute-locationcljs

(get-attribute-location this attribute)

get-programcljs

(get-program this)

get-uniform-locationcljs

(get-uniform-location this uniform)
source

set-uniform!cljs

(set-uniform! program attr dtype v)
source

set-uniforms!cljs

(set-uniforms! program uniforms)
source

use!cljs

(use! program)
source

cljdoc builds & hosts documentation for Clojure/Script libraries