ClojureScript only.

accent.signals


foldpcljs

(foldp step init)

Create a past-dependent signal. Each value given on the input signal will be accumulated, producing a new output value.

Create a past-dependent signal. Each value given on the input signal will be
accumulated, producing a new output value.
sourceraw docstring

relativizecljs

(relativize)

Relativize pointer input (mouse or touch), giving :x and :y data relative to last event.

Relativize pointer input (mouse or touch), giving :x and :y data
relative to last event.
sourceraw docstring

tokenizecljs

(tokenize k)

Transform input into [k input]

Transform input into [k input]
sourceraw docstring

|>cljs

(|> in xf)

Creates new channel and pipes in values from in transduced byxf

Creates new channel and pipes in values from `in transduced by `xf
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries