accent.solids


csg->drawablecljs

(csg->drawable csg)
(csg->drawable csg drawable)

Converts CSG object to drawable. Shared property will be available to shaders as uniform int, and thus is expected to be int in the CSG object.

Converts CSG object to drawable. Shared property will be available to shaders
as uniform int, and thus is expected to be int in the CSG object.
sourceraw docstring

poly->cljcljs

(poly->clj poly)
source

poly->triscljs

(poly->tris poly)
source

quad->triscljs

(quad->tris [a b c d])
source

set-shared!cljs

(set-shared! csg shared)
source

triangulatecljs

(triangulate faces)
source

vec->cljcljs

(vec->clj v)
source

cljdoc builds & hosts documentation for Clojure/Script libraries