(asap)(asap ctrl)Creates a (core.async) channel to be used for drawing frames
as soon as possible, that is, it uses requestAnimationFrame directly.
Optionally pass a control channel, and put :stop onto it to close.
Creates a (core.async) channel to be used for drawing frames as soon as possible, that is, it uses `requestAnimationFrame` directly. Optionally pass a control channel, and put :stop onto it to close.
(fixed fps)(fixed fps ctrl)Creates a (core.async) channel to be used for drawing frames
using requestAnimationFrame with rate limiting using fps (FPS) arg.
Optionally pass a control channel, and put :stop onto it to close.
Creates a (core.async) channel to be used for drawing frames using `requestAnimationFrame` with rate limiting using fps (FPS) arg. Optionally pass a control channel, and put :stop onto it to close.
(request-animation! f)Run f on every animation frame forever.
Run f on every animation frame forever.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |