(check-program program)Checks for program (linking) error and throws if one is found.
Checks for program (linking) error and throws if one is found.
(check-shader shader)Checks for shader (compilation) error and throws if one is found.
Checks for shader (compilation) error and throws if one is found.
(create-program! shaders)(create-program! vs-source fs-source)Creates a program object and checks for linking errors.
Creates a program object and checks for linking errors.
(create-shader! type source)Creates a shader object from given GLSL source, and checks for compilation errors.
Creates a shader object from given GLSL source, and checks for compilation errors.
(get-program-info-log program)Return the information log for a program object.
Return the information log for a program object.
(get-program-parameter program pname)Return a parameter from a program object.
Return a parameter from a program object.
(get-shader-info-log shader)Return the information log for a shader object.
Return the information log for a shader object.
(get-shader-parameter shader pname)Return a parameter from a shader object.
Return a parameter from a shader object.
(get-attribute-location this attribute)(get-program this)(get-uniform-location this uniform)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |