(foldp step init)Create a past-dependent signal. Each value given on the input signal will be accumulated, producing a new output value.
Create a past-dependent signal. Each value given on the input signal will be accumulated, producing a new output value.
(relativize)Relativize pointer input (mouse or touch), giving :x and :y data relative to last event.
Relativize pointer input (mouse or touch), giving :x and :y data relative to last event.
(tokenize k)Transform input into [k input]
Transform input into [k input]
(|> in xf)Creates new channel and pipes in values from in transduced byxf
Creates new channel and pipes in values from `in transduced by `xf
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |